@@ -1,4 +1,4 @@
-from collections.abc import Iterable, Sequence
+from collections.abc import Sequence
 from functools import cached_property
 from os import PathLike
 from pathlib import Path
@@ -12,11 +12,10 @@ from torch import Tensor
 
 from rbyte.config.base import BaseModel
 from rbyte.io.base import TensorSource
-from rbyte.utils.tensor import pad_sequence
 
 
 @final
-class NumpyTensorSource(TensorSource):
+class NumpyTensorSource(TensorSource[object]):
     @validate_call(config=BaseModel.model_config)
     def __init__(
         self, path: PathLike[str], select: Sequence[str] | None = None
@@ -33,15 +32,15 @@ class NumpyTensorSource(TensorSource):
     def _getitem(self, index: object) -> Tensor:
         path = self._path_posix.format(index)
         array = structured_to_unstructured(np.load(path)[self._select])
-        return torch.from_numpy(np.ascontiguousarray(array))  # pyright: ignore[reportUnknownMemberType]
+        return torch.from_numpy(np.ascontiguousarray(array))
 
     @override
-    def __getitem__(self, indexes: object | Iterable[object]) -> Tensor:
+    def __getitem__(self, indexes: object | Sequence[object]) -> Tensor:
         match indexes:
-            case Iterable():
-                tensors = map(self._getitem, indexes)  # pyright: ignore[reportUnknownArgumentType]
+            case Sequence():
+                tensors = map(self._getitem, indexes)
 
-                return pad_sequence(list(tensors), dim=0, value=torch.nan)
+                return torch.stack(list(tensors))
 
             case _:
                 return self._getitem(indexes)
