@@ -5,6 +5,6 @@ from torch import Tensor
 
 
 @runtime_checkable
-class TensorSource(Protocol):
-    def __getitem__[T](self, indexes: T | Sequence[T]) -> Tensor: ...
+class TensorSource[I](Protocol):
+    def __getitem__(self, indexes: I | Sequence[I]) -> Tensor: ...
     def __len__(self) -> int: ...
