@@ -1,13 +1,13 @@
 from .aligner import DataFrameAligner
 from .concater import DataFrameConcater
-from .filter import DataFrameFilter
-from .fps_resampler import DataFrameFpsResampler
+from .groupby import DataFrameGroupByDynamic
 from .indexer import DataFrameIndexer
+from .sql import DataFrameDuckDbQuery
 
 __all__ = [
     "DataFrameAligner",
     "DataFrameConcater",
-    "DataFrameFilter",
-    "DataFrameFpsResampler",
+    "DataFrameDuckDbQuery",
+    "DataFrameGroupByDynamic",
     "DataFrameIndexer",
 ]
