@@ -10,14 +10,14 @@ from rbyte.io.base import TensorSource
 
 
 @final
-class Hdf5TensorSource(TensorSource):
+class Hdf5TensorSource(TensorSource[int]):
     @validate_call
     def __init__(self, path: FilePath, key: str) -> None:
         self._dataset = cast(Dataset, File(path)[key])
 
     @override
     def __getitem__(self, indexes: int | Sequence[int]) -> Tensor:
-        return torch.from_numpy(self._dataset[indexes])  # pyright: ignore[reportUnknownMemberType, reportUnknownArgumentType]
+        return torch.from_numpy(self._dataset[indexes])
 
     @override
     def __len__(self) -> int:
