@@ -1,4 +1,4 @@
-from collections.abc import Callable, Iterable
+from collections.abc import Callable, Sequence
 from functools import cached_property
 from os import PathLike
 from pathlib import Path
@@ -13,7 +13,7 @@ from rbyte.io.base import TensorSource
 
 
 @final
-class PathTensorSource(TensorSource):
+class PathTensorSource(TensorSource[object]):
     @validate_call
     def __init__(
         self, path: PathLike[str], decoder: Callable[[bytes], npt.ArrayLike]
@@ -34,13 +34,13 @@ class PathTensorSource(TensorSource):
     def _getitem(self, index: object) -> Tensor:
         path = self._path_posix.format(index)
         array = self._decode(path)
-        return torch.from_numpy(array)  # pyright: ignore[reportUnknownMemberType]
+        return torch.from_numpy(array)
 
     @override
-    def __getitem__(self, indexes: object | Iterable[object]) -> Tensor:
+    def __getitem__(self, indexes: object | Sequence[object]) -> Tensor:
         match indexes:
-            case Iterable():
-                tensors = map(self._getitem, indexes)  # pyright: ignore[reportUnknownArgumentType]
+            case Sequence():
+                tensors = map(self._getitem, indexes)
 
                 return torch.stack(list(tensors))
 
